Chromium Code Reviews

Unified Diff: chrome/test/automation/automation_proxy_uitest.h

Issue 4202004: Add named testing interface (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Index: chrome/test/automation/automation_proxy_uitest.h
===================================================================
--- chrome/test/automation/automation_proxy_uitest.h (revision 66224)
+++ chrome/test/automation/automation_proxy_uitest.h (working copy)
@@ -112,10 +112,10 @@
class ExternalTabUITest : public UITest {
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
// Override UITest's CreateAutomationProxy to provide the unit test
// with our special implementation of AutomationProxy.
- // This function is called from within UITest::LaunchBrowserAndServer.
- virtual AutomationProxy* CreateAutomationProxy(int execution_timeout);
+ // This function is called from within UITest::SetUp().
+ virtual ProxyLauncher* CreateProxyLauncher();
protected:
// Filtered Inet will override automation callbacks for network resources.
virtual bool ShouldFilterInet() {
@@ -112,10 +112,10 @@
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
- // Override UITest's CreateAutomationProxy to provide the unit test
+ // Override UITest's CreateProxyLauncher to provide the unit test
// with our special implementation of AutomationProxy.

Powered by Google App Engine